# Copyright 2012 Facundo Batista <facundo@taniquetil.com.ar>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Transform the x-ario list of phrases into a RSS."""

import hashlib
import sys
import time


XML = """\
<?xml version="1.0" encoding="utf-8"?>
<rss version="2.0">
<channel>
    <title>Facundario</title>
    <link>http://facundario.taniquetil.com.ar/</link>
    <description>Facundario 2.71 Enterprise Edition (version extra apulentada) </description>

%s

</channel>
</rss>
"""

CONTENT = """\
    <item>
      <title>Facundario</title>
      <link>http://facundario.taniquetil.com.ar/</link>
      <guid>%s</guid>
      <pubDate>%s</pubDate>
      <description>%s</description>
    </item>
"""

def _content(lines):
    """Generate the rss content from the lines."""
    xml = []
    for line in lines:
        line = line.strip()
        unique_id = hashlib.md5(line.encode("utf8")).hexdigest()
        s_date_time = line[:16]
        line_text = line[17:]
        tstamp = time.strptime(s_date_time, "%Y-%m-%d %H:%M")
        s_timestamp = time.strftime("%a, %d %b %Y %H:%M:00 GMT", tstamp)
        xml.append(CONTENT % (unique_id, s_timestamp, line_text))
    return "\n".join(xml)


def main(inp_fname, out_fname):
    """Main entry point."""
    # get latest 20 entries
    with open(inp_fname, encoding='utf8') as fh:
        lines = fh.readlines()
    lines = sorted(lines[-20:], reverse=True)
    xml = XML % (_content(lines),)
    with open(out_fname, 'wt', encoding='utf8') as fh:
        fh.write(xml)


if __name__ == "__main__":
    if len(sys.argv) != 3:
        print("Usage: xario2rss.py input_file output_file")
        exit()

    main(*sys.argv[1:])
